==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.get_dx = function () {
        return true;
    };
    PolarLineSeries.prototype.bv = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.lo = function (a) {
        _super.prototype.lo.call(this, a);
        this.ur = a;
    };
    PolarLineSeries.prototype.up = function (a) {
        var b = a;
        b.c5();
    };
    PolarLineSeries.prototype.uq = function (a, b) {
        var c = b;
        c.c6(a.m, this.gk);
        this.rt.ax(this, this.sg(), runOn(this, this.q6));
        var d = false;
        var e = this.rt.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.tg(-1, this.r2.count, b.q);
        }
        this.rt.ad(b.c8, true, false, true, false);
    };
    PolarLineSeries.prototype.uh = function () {
        return this.us;
    };
    PolarLineSeries.prototype.lt = function (a, b, c, d) {
        _super.prototype.lt.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.l7(false);
                this.le();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:us:uu', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.c8 = new Path();
        _this.c7 = new Path();
        _this.c4 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.p0 = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.c5 = function () {
        this.c8.ak = null;
        this.c7.ak = null;
        this.aq();
    };
    PolarLineSeriesView.prototype.c6 = function (a, b) {
        this.c4.ue.d(this.c8, a, b);
        this.aq();
    };
    PolarLineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    PolarLineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c7.ak = this.c8.ak;
        this.c7._stroke = a;
        this.c7.ac = this.e.fn + 3;
    };
    PolarLineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
            }
            else {
                a.s(this.c8);
            }
        }
    };
    PolarLineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a7.exportPathData(a, this.c8, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };

==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.get_d1 = function () {
        return true;
    };
    PolarLineSeries.prototype.bx = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.vg = a;
    };
    PolarLineSeries.prototype.ve = function (a) {
        var b = a;
        b.c5();
    };
    PolarLineSeries.prototype.vf = function (a, b) {
        var c = b;
        c.c6(a.m, this.ft);
        this.r6.ax(this, this.st(), runOn(this, this.rj));
        var d = false;
        var e = this.r6.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.t1(-1, this.sf.count, b.q);
        }
        this.r6.ad(b.c8, true, false, true, false);
    };
    PolarLineSeries.prototype.u6 = function () {
        return this.vh;
    };
    PolarLineSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.mi(false);
                this.lp();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vh:vj', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.c8 = new Path();
        _this.c7 = new Path();
        _this.c4 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.qd = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.c5 = function () {
        this.c8.ak = null;
        this.c7.ak = null;
        this.aq();
    };
    PolarLineSeriesView.prototype.c6 = function (a, b) {
        this.c4.u3.d(this.c8, a, b);
        this.aq();
    };
    PolarLineSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    PolarLineSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c7.ak = this.c8.ak;
        this.c7._stroke = a;
        this.c7.ac = this.e.fu + 3;
    };
    PolarLineSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
            }
            else {
                a.s(this.c8);
            }
        }
    };
    PolarLineSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.c8, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };
